diff --git a/Settings.ui b/Settings.ui
index 6cee3a0..4e37cb6 100644
--- a/Settings.ui
+++ b/Settings.ui
@@ -8,273 +8,6 @@
0.01
0.10000000000000001
-
-
True
False
@@ -519,6 +252,256 @@
1
5
+
+ 0.33000000000000002
+ 1
+ 0.01
+ 0.10000000000000001
+
+
+ True
+ False
+ 12
+ 12
+ vertical
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 0
+ in
+
+
+ True
+ False
+ none
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Color - Override Theme
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ False
+ 6
+
+
+ True
+ True
+ True
+
+
+ False
+ True
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ False
+ True
+ 1
+
+
+
+
+ 1
+ 0
+
+
+
+
+
+
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Height - Override Theme
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 0
+
+
+
+
+ True
+ True
+ baseline
+ True
+ dots_height_adjustment
+ 0
+ 0
+ right
+
+
+ 0
+ 1
+ 2
+
+
+
+
+
+
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Highlight focused application
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 0
+
+
+
+
+
+
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Stacked appearance for multiple windows
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 0
+
+
+
+
+
+
+
+
+
+
+ False
+ True
+ 0
+
+
+
9999
25
@@ -636,6 +619,274 @@
25
100
+
+ 10000
+ 250
+ 1000
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ vertical
+
+
+ True
+ False
+ 0
+ in
+
+
+ True
+ False
+ none
+
+
+ 100
+ 80
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ center
+
+ - Super
+ - Super + Alt
+
+
+
+ 1
+ 0
+ 2
+
+
+
+
+ True
+ False
+ True
+ Hotkeys prefix
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ False
+ Hotkeys will either be Super+Number or Super+Alt+Num
+ True
+ 40
+ 0
+
+
+
+ 0
+ 1
+
+
+
+
+
+
+
+
+ 100
+ 80
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 0
+ 2
+
+
+
+
+ True
+ False
+ True
+ Number overlay
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ False
+ Temporarily show the application numbers over the icons when using the hotkeys.
+ True
+ 40
+ 0
+
+
+
+ 0
+ 1
+
+
+
+
+
+
+
+
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ True
+ 6
+ 32
+
+
+ True
+ True
+ end
+ shortcut_time_adjustment
+
+
+ 1
+ 0
+
+
+
+
+ True
+ False
+ True
+ Hide timeout (ms)
+ 0
+
+
+ 0
+ 0
+
+
+
+
+
+
+
+
+
+
+
+
+
+ False
+ True
+ 0
+
+
+
0.33000000000000002
1
@@ -782,7 +1033,8 @@
True
False
- Panel Size
+ Panel Size
+(default is 48)
0
@@ -812,6 +1064,56 @@
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ App Icon Margin
+(default is 8)
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ True
+ baseline
+ True
+ appicon_margin_adjustment
+ 0
+ 0
+ right
+
+
+
+
+ 1
+ 0
+
+
+
+
+
+
@@ -838,7 +1140,6 @@
100
- 80
True
True
@@ -855,7 +1156,7 @@
True
False
True
- Running indicator (dots) position
+ Running indicator position
0
@@ -919,6 +1220,139 @@
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Running indicator style (Focused app)
+ 0
+
+
+ False
+ True
+ 0
+
+
+
+
+ True
+ False
+ 6
+
+
+ True
+ True
+ True
+ center
+
+
+ True
+ False
+ emblem-system-symbolic
+
+
+
+
+
+ False
+ True
+ 0
+
+
+
+
+ True
+ False
+ end
+ center
+
+ - Line
+ - Dots
+
+
+
+ False
+ True
+ 1
+
+
+
+
+ False
+ True
+ 1
+
+
+
+
+
+
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 32
+
+
+ True
+ False
+ True
+ Running indicator style (Unfocused apps)
+ 0
+
+
+ False
+ True
+ 0
+
+
+
+
+ True
+ False
+ end
+ center
+
+ - Line
+ - Dots
+
+
+
+ False
+ True
+ 1
+
+
+
+
+
+
@@ -961,6 +1395,7 @@
True
False
+ True
Clock location
0
@@ -1020,6 +1455,7 @@
24
24
24
+ 24
vertical
24
@@ -1204,6 +1640,7 @@
12
12
12
+ 4
32
@@ -1535,6 +1972,11 @@
end
center
+
+ False
+ True
+ 1
+
@@ -1585,79 +2027,6 @@
24
vertical
24
-
-
- True
- False
- 0
- in
-
-
- True
- False
- none
-
-
- 100
- True
- True
-
-
- True
- False
- 12
- 12
- 12
- 12
- 12
- 32
-
-
- True
- False
- App Icon Margin
-(default is 8)
- 0
-
-
- 0
- 0
-
-
-
-
- True
- True
- baseline
- True
- appicon_margin_adjustment
- 0
- 0
- right
-
-
-
-
- 1
- 0
-
-
-
-
-
-
-
-
-
-
-
-
-
- False
- True
- 0
-
-
True
@@ -1759,7 +2128,7 @@
False
True
- 1
+ 0
@@ -1887,6 +2256,95 @@
+
+
+ False
+ True
+ 1
+
+
+
+
+ True
+ False
+ 0
+ in
+
+
+ True
+ False
+ none
+
+
+ 100
+ True
+ True
+
+
+ True
+ False
+ 12
+ 12
+ 12
+ 12
+ 20
+ 32
+
+
+ True
+ False
+ True
+ Animate switching applications
+ 0
+
+
+ 0
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 0
+
+
+
+
+ True
+ True
+ end
+ center
+
+
+ 1
+ 1
+
+
+
+
+ True
+ False
+ True
+ Animate launching new windows
+ 0
+
+
+ 0
+ 1
+
+
+
+
+
+
+
+
diff --git a/taskbar.js b/taskbar.js
index d0ba112..2c39898 100644
--- a/taskbar.js
+++ b/taskbar.js
@@ -54,7 +54,7 @@ let DASH_ITEM_LABEL_SHOW_TIME = Dash.DASH_ITEM_LABEL_SHOW_TIME;
let DASH_ITEM_LABEL_HIDE_TIME = Dash.DASH_ITEM_LABEL_HIDE_TIME;
let DASH_ITEM_HOVER_TIMEOUT = Dash.DASH_ITEM_HOVER_TIMEOUT;
let LABEL_GAP = 5;
-let RUNNING_INDICATOR_SIZE = 3;
+let RUNNING_INDICATOR_SIZE = 1;
let HFADE_WIDTH = 48;
function getPosition() {
diff --git a/prefs.js b/prefs.js
index 9f6f96c..036a4c0 100644
--- a/prefs.js
+++ b/prefs.js
@@ -77,7 +77,7 @@ const Settings = new Lang.Class({
},
_bindSettings: function() {
// Position and size panel
// Position option
let position = this._settings.get_string('panel-position');
@@ -129,6 +129,43 @@ const Settings = new Lang.Class({
}
+ this._builder.get_object('dots_style_options_button').connect('clicked', Lang.bind(this, function() {
+
+ let dialog = new Gtk.Dialog({ title: _('Running Indicator Options'),
+ transient_for: this.widget.get_toplevel(),
+ use_header_bar: true,
+ modal: true });
+
+ // GTK+ leaves positive values for application-defined response ids.
+ // Use +1 for the reset action
+ dialog.add_button(_('Reset to defaults'), 1);
+
+ let box = this._builder.get_object('box_dots_options');
+ dialog.get_content_area().add(box);
+
+ // this._builder.get_object('leave_timeout_spinbutton').set_value(this._settings.get_int('leave-timeout'));
+
+ // this._builder.get_object('leave_timeout_spinbutton').connect('value-changed', Lang.bind (this, function(widget) {
+ // this._settings.set_int('leave-timeout', widget.get_value());
+ // }));
+
+ dialog.connect('response', Lang.bind(this, function(dialog, id) {
+ if (id == 1) {
+ // restore default settings
+ // this._settings.set_int('leave-timeout', 100);
+ // this._builder.get_object('leave_timeout_spinbutton').set_value(this._settings.get_int('leave-timeout'));
+ } else {
+ // remove the settings box so it doesn't get destroyed;
+ dialog.get_content_area().remove(box);
+ dialog.destroy();
+ }
+ return;
+ }));
+
+ dialog.show_all();
+
+ }));
+
// Behavior panel
this._settings.bind('show-show-apps-button',
@@ -360,7 +397,7 @@ const Settings = new Lang.Class({
}));
- // Appearance panel
+ // Fine-tune panel
let sizeScales = [
{objectName: 'tray_size_scale', valueName: 'tray-size', range: DEFAULT_FONT_SIZES },
@@ -77,7 +77,7 @@ const Settings = new Lang.Class({
},
_bindSettings: function() {
- // Position and size panel
+ // Position and style panel
// Position option
let position = this._settings.get_string('panel-position');